@@ -131,7 +131,7 @@ class VariableList2D:
 
     @property
     def y(self):
-        return Value1D(f"Y {self.name}", self.unit, self.x_values[-1], self.x_values)
+        return Value1D(f"Y {self.name}", self.unit, self.y_values[-1], self.y_values)
 
     @property
     def magnitude(self):
